@@ -12,7 +12,15 @@ if [ "$tmp" = "" ]; then
 	exit 1
 fi
 
+tmp=`which libtoolize`
+if [ "$tmp" = "" ]; then
+	echo "ERROR: You need to install libtool!"
+	exit 1
+fi
+
 autoreconf -i
 intltoolize
+if test -z "$NOCONFIGURE"; then
 ./configure "$@"
+fi
 
