@@ -53,7 +53,7 @@ typedef struct feed {
 	/* feed parsing state */
 	gboolean	valid;			/**< FALSE if there was an error in xml_parse_feed() */
 	GString		*parseErrors;		/**< textual description of parsing errors */
-	time_t		time;			/**< Feeds modified date */
+	gint64		time;			/**< Feeds modified date */
 
 	/* feed specific behaviour settings */
 	gboolean	encAutoDownload;	/**< if TRUE do automatically download enclosures */
