@@ -1,7 +1,7 @@
-/**
+/*
  * @file feedlist.c  subscriptions as an hierarchic tree
  *
- * Copyright (C) 2005-2011 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2013 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2005-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *	      
  * This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 #include <libxml/uri.h>
 
+#include "comments.h"
 #include "common.h"
 #include "conf.h"
 #include "db.h"
@@ -36,8 +37,7 @@
 #include "ui/feed_list_view.h"
 #include "ui/itemview.h"
 #include "ui/liferea_shell.h"
-#include "ui/ui_node.h"
-#include "ui/ui_tray.h"
+#include "ui/feed_list_node.h"
 #include "fl_sources/node_source.h"
 
 static void feedlist_save	(void);
@@ -45,24 +45,32 @@ static void feedlist_save	(void);
 #define FEEDLIST_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), FEEDLIST_TYPE, FeedListPrivate))
 
 struct FeedListPrivate {
-	guint		newCount;	/**< overall new item count */
+	guint		newCount;	/*<< overall new item count */
 
-	nodePtr		rootNode;	/**< the feed list root node */
-	nodePtr		selectedNode;	/**< matches the node selected in the feed list tree view, which
+	nodePtr		rootNode;	/*<< the feed list root node */
+	nodePtr		selectedNode;	/*<< matches the node selected in the feed list tree view, which
 					     is not necessarily the displayed one (e.g. folders without recursive
 					     display enabled) */
 
-	guint		saveTimer;	/**< timer id for delayed feed list saving */
-	guint		autoUpdateTimer; /**< timer id for auto update */
+	guint		saveTimer;	/*<< timer id for delayed feed list saving */
+	guint		autoUpdateTimer; /*<< timer id for auto update */
 
-	gboolean	loading;	/**< prevents the feed list being saved before it is completely loaded */
+	gboolean	loading;	/*<< prevents the feed list being saved before it is completely loaded */
+};
+
+enum {
+	NEW_ITEMS,		/*<< node has new items after update */
+	NODE_UPDATED,		/*<< node display info (title, unread count) has changed */
+	LAST_SIGNAL
 };
 
 #define ROOTNODE feedlist->priv->rootNode
 #define SELECTED feedlist->priv->selectedNode
 
+static guint feedlist_signals[LAST_SIGNAL] = { 0 };
+
 static GObjectClass *parent_class = NULL;
-static FeedList *feedlist = NULL;
+FeedList *feedlist = NULL;
 
 G_DEFINE_TYPE (FeedList, feedlist, G_TYPE_OBJECT);
 
@@ -80,19 +88,31 @@ static void
 feedlist_finalize (GObject *object)
 {
 	/* Stop all timer based activity */
-	if (feedlist->priv->autoUpdateTimer)
+	if (feedlist->priv->autoUpdateTimer) {
 		g_source_remove (feedlist->priv->autoUpdateTimer);
-	if (feedlist->priv->saveTimer)
+		feedlist->priv->autoUpdateTimer = 0;
+	}
+	if (feedlist->priv->saveTimer) {
 		g_source_remove (feedlist->priv->saveTimer);
+		feedlist->priv->saveTimer = 0;
+	}
 
 	/* Enforce synchronous save upon exit */
 	feedlist_save ();		
+
+	/* Save last selection for next start */
+	if (feedlist->priv->selectedNode)
+		conf_set_str_value (LAST_NODE_SELECTED, feedlist->priv->selectedNode->id);
+
 	
 	/* And destroy everything */
 	feedlist_foreach (feedlist_free_node);
 	node_free (ROOTNODE);
 	ROOTNODE = NULL;
 
+	/* This might also be a good place to get for some other cleanup */
+	comments_deinit ();
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -105,6 +125,30 @@ feedlist_class_init (FeedListClass *klass)
 
 	object_class->finalize = feedlist_finalize;
 
+	feedlist_signals[NEW_ITEMS] = 
+		g_signal_new ("new-items", 
+		G_OBJECT_CLASS_TYPE (object_class),
+		(GSignalFlags)(G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION),
+		0, 
+		NULL,
+		NULL,
+		g_cclosure_marshal_VOID__POINTER,
+		G_TYPE_NONE,
+		1,
+		G_TYPE_POINTER);
+
+	feedlist_signals[NODE_UPDATED] = 
+		g_signal_new ("node-updated", 
+		G_OBJECT_CLASS_TYPE (object_class),
+		(GSignalFlags)(G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION),
+		0, 
+		NULL,
+		NULL,
+		g_cclosure_marshal_VOID__STRING,
+		G_TYPE_NONE,
+		1,
+		G_TYPE_STRING);
+
 	g_type_class_add_private (object_class, sizeof(FeedListPrivate));
 }
 
@@ -134,13 +178,13 @@ static void
 feedlist_init_node (nodePtr node) 
 {
 	if (node->expanded)
-		ui_node_set_expansion (node, TRUE);
+		feed_list_node_set_expansion (node, TRUE);
 	
 	if (node->subscription)
 		db_subscription_load (node->subscription);
 		
 	node_update_counters (node);
-	ui_node_update (node->id);	/* Necessary to initially set folder unread counters */
+	feed_list_node_update (node->id);	/* Necessary to initially set folder unread counters */
 	
 	node_foreach_child (node, feedlist_init_node);
 }
@@ -167,8 +211,6 @@ feedlist_init (FeedList *fl)
 	debug0 (DEBUG_CACHE, "Initializing node state");
 	feedlist_foreach (feedlist_init_node);
 
-	ui_tray_update ();
-
 	/* 4. Check if feeds do need updating. */
 	debug0 (DEBUG_UPDATE, "Performing initial feed update");
 	conf_get_int_value (STARTUP_FEED_ACTION, &startup_feed_action);
@@ -185,11 +227,14 @@ feedlist_init (FeedList *fl)
 		feedlist_reset_update_counters (NULL);
 	}
 
-	/* 5. Start automatic updating */
+	/* 5. Purge old nodes from the database */
+	db_node_cleanup (feedlist_get_root ());
+
+	/* 6. Start automatic updating */
 	feedlist->priv->autoUpdateTimer = g_timeout_add_seconds (10, feedlist_auto_update, NULL);
 	g_signal_connect (network_monitor_get (), "online-status-changed", G_CALLBACK (on_network_status_changed), NULL);
 
-	/* 6. Finally save the new feed list state */
+	/* 7. Finally save the new feed list state */
 	feedlist->priv->loading = FALSE;
 	feedlist_schedule_save ();
 	
@@ -228,6 +273,49 @@ feedlist_get_parent_node (void)
 	return ROOTNODE;
 }
 
+nodePtr
+feedlist_find_node (nodePtr parent, feedListFindType type, const gchar *str)
+{
+	GSList	*iter;
+
+	g_assert (str);
+
+	iter = parent->children;
+	while (iter) {
+		gboolean found = FALSE;
+		nodePtr result, node = (nodePtr)iter->data;
+
+		/* Check child node */
+		switch (type) {
+			case NODE_BY_URL:
+				if (node->subscription)
+					found = g_str_equal (str, subscription_get_source (node->subscription));
+				break;
+			case NODE_BY_ID:
+				found = g_str_equal (str, node->id);
+				break;
+			case FOLDER_BY_TITLE:
+				if (IS_FOLDER (node))
+					found = g_str_equal (str, node->title);
+				break;
+
+			default:
+				break;
+		}
+		if (found)
+			return node;
+
+		/* And recurse */
+		result = feedlist_find_node (node, type, str);
+		if (result)
+			return result;
+
+		iter = g_slist_next (iter);
+	}
+
+	return NULL;
+}
+
 gboolean
 feedlist_is_writable (void)
 {
@@ -244,7 +332,7 @@ feedlist_update_node_counters (nodePtr node)
 	node_update_counters (node);	/* update with parent propagation */
 
 	if (node->needsUpdate)
-		ui_node_update (node->id);
+		feed_list_node_update (node->id);
 	if (node->children)
 		node_foreach_child (node, feedlist_update_node_counters);
 }
@@ -263,6 +351,7 @@ feedlist_mark_all_read (nodePtr node)
 		node_foreach_child (ROOTNODE, node_mark_all_read);
 		
 	feedlist_foreach (feedlist_update_node_counters);
+	itemview_select_item (NULL);
 	itemview_update_all_items ();
 	itemview_update ();
 }
@@ -287,37 +376,13 @@ feedlist_get_new_item_count (void)
 	return (feedlist->priv->newCount > 0)?feedlist->priv->newCount:0;
 }
 
-void
-feedlist_update_new_item_count (guint addValue)
-{
-	feedlist->priv->newCount += addValue;
-	
-	/* On subsequent feed updates with cache drops
-	   more new items can be reported than effectively
-	   were merged. The simplest way to catch this case
-	   is by checking for new count > unread count here. */
-	if (feedlist->priv->newCount > ROOTNODE->unreadCount)
-		feedlist->priv->newCount = ROOTNODE->unreadCount;
-		
-	ui_tray_update ();
-	liferea_shell_update_unread_stats ();
-}
-
 void
 feedlist_reset_new_item_count (void)
 {
-	if (feedlist->priv->newCount) {
+	if (feedlist->priv->newCount)
 		feedlist->priv->newCount = 0;
-		ui_tray_update ();
-		liferea_shell_update_unread_stats ();
-	}
-}
 
-void
-feedlist_node_was_updated (nodePtr node, guint newCount)
-{
-	node_update_counters (node);
-	feedlist_update_new_item_count (newCount);
+	feedlist_new_items (0);
 }
 
 void
@@ -355,7 +420,8 @@ feedlist_add_subscription (const gchar *source, const gchar *filter, updateOptio
 void
 feedlist_node_imported (nodePtr node)
 {
-	ui_node_add (node);	
+	feed_list_node_add (node);	
+
 	feedlist_schedule_save ();
 }
 
@@ -366,7 +432,7 @@ feedlist_node_added (nodePtr node)
 	
 	g_assert (NULL == node->parent);
 	
-	if (SELECTED && !IS_FOLDER(SELECTED)) {
+	if (SELECTED && !IS_FOLDER (SELECTED)) {
 		position = g_slist_index (SELECTED->parent->children, SELECTED);
 		if (position > -1)
 			position++;	/* insert after selected child index */
@@ -377,7 +443,7 @@ feedlist_node_added (nodePtr node)
 	if (node->subscription)
 		db_subscription_update (node->subscription);
 	
-	db_node_update(node);
+	db_node_update (node);
 
 	feedlist_node_imported (node);
 	
@@ -404,7 +470,7 @@ feedlist_node_removed (nodePtr node)
 
 	node_remove (node);
 
-	ui_node_remove_node (node);
+	feed_list_node_remove_node (node);
 
 	node->parent->children = g_slist_remove (node->parent->children, node);
 
@@ -539,11 +605,12 @@ feedlist_selection_changed (nodePtr node)
 static gboolean
 feedlist_schedule_save_cb (gpointer user_data)
 {
-	/* step 1: request each node to save its state */
+	/* step 1: request each node to save its state, that is 
+	   mostly needed for nodes that are node sources */
 	feedlist_foreach (node_save);
 
 	/* step 2: request saving for the root node and thereby
-	   forcing the root plugin to save the feed list structure */
+	   forcing the default source to write an OPML file */
 	NODE_SOURCE_TYPE (ROOTNODE)->source_export (ROOTNODE);
 	
 	feedlist->priv->saveTimer = 0;
@@ -565,6 +632,32 @@ feedlist_schedule_save (void)
 	feedlist->priv->saveTimer = g_timeout_add_seconds (5, feedlist_schedule_save_cb, NULL);
 }
 
+/* Handling updates */
+
+void
+feedlist_new_items (guint newCount)
+{
+	feedlist->priv->newCount += newCount;
+	
+	/* On subsequent feed updates with cache drops
+	   more new items can be reported than effectively
+	   were merged. The simplest way to catch this case
+	   is by checking for new count > unread count here. */
+	if (feedlist->priv->newCount > ROOTNODE->unreadCount)
+		feedlist->priv->newCount = ROOTNODE->unreadCount;
+
+	g_signal_emit_by_name (feedlist, "new-items", feedlist->priv->newCount);
+}
+
+void
+feedlist_node_was_updated (nodePtr node)
+{
+	node_update_counters (node);
+	feedlist_schedule_save ();
+
+	g_signal_emit_by_name (feedlist, "node-updated", node->title);
+}
+
 /* This method is only to be used when exiting the program! */
 static void
 feedlist_save (void)
