@@ -1,7 +1,7 @@
 /**
  * @file theoldreader_source.c  TheOldReader feed list source support
  * 
- * Copyright (C) 2007-2014 Lars Windolf <lars.lindner@gmail.com>
+ * Copyright (C) 2007-2016 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2008 Arnold Noronha <arnstein87@gmail.com>
  * Copyright (C) 2011 Peter Oliver
  * Copyright (C) 2011 Sergey Snitsaruk <narren96c@gmail.com>
@@ -25,23 +25,21 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <string.h>
-#include <libxml/xpath.h>
 
 #include "common.h"
 #include "debug.h"
 #include "feedlist.h"
+#include "folder.h"
 #include "item_state.h"
 #include "metadata.h"
 #include "node.h"
 #include "subscription.h"
 #include "update.h"
-#include "xml.h"
 #include "ui/auth_dialog.h"
 #include "ui/liferea_dialog.h"
 #include "fl_sources/node_source.h"
 #include "fl_sources/opml_source.h"
-#include "fl_sources/theoldreader_source_edit.h"
+#include "fl_sources/google_reader_api_edit.h"
 #include "fl_sources/theoldreader_source_feed_list.h"
 
 /** default TheOldReader subscription list update interval = once a day */
@@ -53,38 +51,34 @@ theoldreader_source_new (nodePtr node)
 {
 	TheOldReaderSourcePtr source = g_new0 (struct TheOldReaderSource, 1) ;
 	source->root = node; 
-	source->actionQueue = g_queue_new (); 
-	source->loginState = THEOLDREADER_SOURCE_STATE_NONE; 
 	source->lastTimestampMap = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	source->folderToCategory = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	
 	return source;
 }
 
 static void
-theoldreader_source_free (TheOldReaderSourcePtr gsource) 
+theoldreader_source_free (TheOldReaderSourcePtr source) 
 {
-	if (!gsource)
+	if (!source)
 		return;
 
-	update_job_cancel_by_owner (gsource);
+	update_job_cancel_by_owner (source);
 	
-	g_free (gsource->authHeaderValue);
-	g_queue_free (gsource->actionQueue) ;
-	g_hash_table_unref (gsource->lastTimestampMap);
-	g_free (gsource);
+	g_hash_table_unref (source->lastTimestampMap);
+	g_hash_table_destroy (source->folderToCategory);
+	g_free (source);
 }
 
 static void
 theoldreader_source_login_cb (const struct updateResult * const result, gpointer userdata, updateFlags flags)
 {
-	TheOldReaderSourcePtr	gsource = (TheOldReaderSourcePtr) userdata;
-	gchar		*tmp = NULL;
-	subscriptionPtr subscription = gsource->root->subscription;
+	nodePtr			node = (nodePtr) userdata;
+	gchar			*tmp = NULL;
+	subscriptionPtr 	subscription = node->subscription;
 		
 	debug1 (DEBUG_UPDATE, "TheOldReader login processing... %s", result->data);
-	
-	g_assert (!gsource->authHeaderValue);
-	
+		
 	if (result->data && result->httpstatus == 200)
 		tmp = strstr (result->data, "Auth=");
 		
@@ -93,32 +87,22 @@ theoldreader_source_login_cb (const struct updateResult * const result, gpointer
 		tmp = strchr (tmp, '\n');
 		if (tmp)
 			*tmp = '\0';
-		gsource->authHeaderValue = g_strdup_printf ("GoogleLogin auth=%s", ttmp + 5);
-
-		debug1 (DEBUG_UPDATE, "TheOldReader Auth token found: %s", gsource->authHeaderValue);
-
-		gsource->loginState = THEOLDREADER_SOURCE_STATE_ACTIVE;
-		gsource->authFailures = 0;
+		node_source_set_auth_token (node, g_strdup_printf ("GoogleLogin auth=%s", ttmp + 5));
 
 		/* now that we are authenticated trigger updating to start data retrieval */
-		if (!(flags & THEOLDREADER_SOURCE_UPDATE_ONLY_LOGIN))
+		if (!(flags & NODE_SOURCE_UPDATE_ONLY_LOGIN))
 			subscription_update (subscription, flags);
 
 		/* process any edits waiting in queue */
-		theoldreader_source_edit_process (gsource);
+		google_reader_api_edit_process (node->source);
 
 	} else {
 		debug0 (DEBUG_UPDATE, "TheOldReader login failed! no Auth token found in result!");
 		subscription->node->available = FALSE;
 
 		g_free (subscription->updateError);
-		subscription->updateError = g_strdup (_("TheOldReader login failed!"));
-		gsource->authFailures++;
-
-		if (gsource->authFailures < THEOLDREADER_SOURCE_MAX_AUTH_FAILURES)
-			gsource->loginState = THEOLDREADER_SOURCE_STATE_NONE;
-		else
-			gsource->loginState = THEOLDREADER_SOURCE_STATE_NO_AUTH;
+		subscription->updateError = g_strdup (_("Login failed!"));
+		node_source_set_state (node, NODE_SOURCE_STATE_NO_AUTH);
 		
 		auth_dialog_new (subscription, flags);
 	}
@@ -127,19 +111,19 @@ theoldreader_source_login_cb (const struct updateResult * const result, gpointer
 /**
  * Perform a login to TheOldReader, if the login completes the 
  * TheOldReaderSource will have a valid Auth token and will have loginStatus to 
- * THEOLDREADER_SOURCE_LOGIN_ACTIVE.
+ * NODE_SOURCE_LOGIN_ACTIVE.
  */
 void
-theoldreader_source_login (TheOldReaderSourcePtr gsource, guint32 flags) 
+theoldreader_source_login (TheOldReaderSourcePtr source, guint32 flags) 
 { 
 	gchar			*username, *password;
 	updateRequestPtr	request;
-	subscriptionPtr		subscription = gsource->root->subscription;
+	subscriptionPtr		subscription = source->root->subscription;
 	
-	if (gsource->loginState != THEOLDREADER_SOURCE_STATE_NONE) {
+	if (source->root->source->loginState != NODE_SOURCE_STATE_NONE) {
 		/* this should not happen, as of now, we assume the session
 		 * doesn't expire. */
-		debug1(DEBUG_UPDATE, "Logging in while login state is %d\n", gsource->loginState);
+		debug1(DEBUG_UPDATE, "Logging in while login state is %d\n", source->root->source->loginState);
 	}
 
 	request = update_request_new ();
@@ -156,58 +140,44 @@ theoldreader_source_login (TheOldReaderSourcePtr gsource, guint32 flags)
 	g_free (username);
 	g_free (password);
 
-	gsource->loginState = THEOLDREADER_SOURCE_STATE_IN_PROGRESS ;
+	node_source_set_state (source->root, NODE_SOURCE_STATE_IN_PROGRESS);
 
-	update_execute_request (gsource, request, theoldreader_source_login_cb, gsource, flags);
+	update_execute_request (source, request, theoldreader_source_login_cb, source->root, flags);
 }
 
 /* node source type implementation */
 
-static void
-theoldreader_source_update (nodePtr node)
-{
-	TheOldReaderSourcePtr gsource = (TheOldReaderSourcePtr) node->data;
-
-	/* Reset THEOLDREADER_SOURCE_STATE_NO_AUTH as this is a manual
-	   user interaction and no auto-update so we can query
-	   for credentials again. */
-	if (gsource->loginState == THEOLDREADER_SOURCE_STATE_NO_AUTH)
-		gsource->loginState = THEOLDREADER_SOURCE_STATE_NONE;
-
-	subscription_update (node->subscription, 0);  // FIXME: 0 ?
-}
-
 static void
 theoldreader_source_auto_update (nodePtr node)
 {
 	GTimeVal	now;
-	TheOldReaderSourcePtr gsource = (TheOldReaderSourcePtr) node->data;
+	TheOldReaderSourcePtr source = (TheOldReaderSourcePtr) node->data;
 
-	if (gsource->loginState == THEOLDREADER_SOURCE_STATE_NONE) {
-		theoldreader_source_update (node);
+	if (node->source->loginState == NODE_SOURCE_STATE_NONE) {
+		node_source_update (node);
 		return;
 	}
 
-	if (gsource->loginState == THEOLDREADER_SOURCE_STATE_IN_PROGRESS) 
+	if (node->source->loginState == NODE_SOURCE_STATE_IN_PROGRESS) 
 		return; /* the update will start automatically anyway */
 
 	g_get_current_time (&now);
 	
 	/* do daily updates for the feed list and feed updates according to the default interval */
-/*	if (node->subscription->updateState->lastPoll.tv_sec + THEOLDREADER_SOURCE_UPDATE_INTERVAL <= now.tv_sec) {
+/*	if (node->subscription->updateState->lastPoll.tv_sec + NODE_SOURCE_UPDATE_INTERVAL <= now.tv_sec) {
 		subscription_update (node->subscription, 0);
-		g_get_current_time (&gsource->lastQuickUpdate);
+		g_get_current_time (&source->lastQuickUpdate);
 	}
-	else if (gsource->lastQuickUpdate.tv_sec + THEOLDREADER_SOURCE_QUICK_UPDATE_INTERVAL <= now.tv_sec) {
-		theoldreader_source_opml_quick_update (gsource);
-		theoldreader_source_edit_process (gsource);
-		g_get_current_time (&gsource->lastQuickUpdate);
+	else if (source->lastQuickUpdate.tv_sec + NODE_SOURCE_QUICK_UPDATE_INTERVAL <= now.tv_sec) {
+		theoldreader_source_opml_quick_update (source);
+		google_reader_api_edit_process (node->source);
+		g_get_current_time (&source->lastQuickUpdate);
 	}*/
 
-	// FIXME: Don't do below, but about logic!
-	if (gsource->lastQuickUpdate.tv_sec + THEOLDREADER_SOURCE_QUICK_UPDATE_INTERVAL <= now.tv_sec) {
+	// FIXME: Don't do below, but above logic!
+	if (source->lastQuickUpdate.tv_sec + THEOLDREADER_SOURCE_QUICK_UPDATE_INTERVAL <= now.tv_sec) {
 		subscription_update (node->subscription, 0);
-		g_get_current_time (&gsource->lastQuickUpdate);
+		g_get_current_time (&source->lastQuickUpdate);
 	}
 }
 
@@ -219,92 +189,62 @@ void theoldreader_source_init (void)
 
 static void theoldreader_source_deinit (void) { }
 
-static void
-theoldreader_source_import_node (nodePtr node)
-{
-	GSList *iter; 
-	for (iter = node->children; iter; iter = g_slist_next(iter)) {
-		nodePtr subnode = iter->data;
-		if (subnode->subscription)
-			subnode->subscription->type = &theOldReaderSourceFeedSubscriptionType; 
-		if (subnode->type->capabilities
-		    & NODE_CAPABILITY_SUBFOLDERS)
-			theoldreader_source_import_node (subnode);
-	}
-}
-
 static void
 theoldreader_source_import (nodePtr node)
 {
 	opml_source_import (node);
 	
 	node->subscription->updateInterval = -1;
-	node->subscription->type = &theOldReaderSourceOpmlSubscriptionType;
+	node->subscription->type = node->source->type->sourceSubscriptionType;
 	if (!node->data)
 		node->data = (gpointer) theoldreader_source_new (node);
-
-	theoldreader_source_import_node (node);
-}
-
-static void
-theoldreader_source_export (nodePtr node)
-{
-	opml_source_export (node);
-}
-
-static gchar *
-theoldreader_source_get_feedlist (nodePtr node)
-{
-	return opml_source_get_feedlist (node);
-}
-
-static void 
-theoldreader_source_remove (nodePtr node)
-{ 
-	opml_source_remove (node);
 }
 
 static nodePtr
-theoldreader_source_add_subscription (nodePtr node, subscriptionPtr subscription) 
-{ 
-	debug_enter ("theoldreader_source_add_subscription");
-	nodePtr child = node_new (feed_get_node_type ());
+theoldreader_source_add_subscription (nodePtr root, subscriptionPtr subscription) 
+{
+	nodePtr			parent;
+	gchar			*categoryId = NULL;
+	TheOldReaderSourcePtr	source = (TheOldReaderSourcePtr)root->data;
 
-	debug0 (DEBUG_UPDATE, "TheOldReaderSource: Adding a new subscription"); 
-	node_set_data (child, feed_new ());
 
-	node_set_subscription (child, subscription);
-	child->subscription->type = &theOldReaderSourceFeedSubscriptionType;
-	
-	node_set_title (child, _("New Subscription"));
 
-	theoldreader_source_edit_add_subscription (node_source_root_from_node (node)->data, subscription->source);
+	/* Determine correct category from selected folder name */
+	parent = feedlist_get_selected ();
+	if (parent) {
+		if (parent->subscription)
+			parent = parent->parent;
+		categoryId = g_hash_table_lookup (source->folderToCategory, parent->id);
+	}
+
+	google_reader_api_edit_add_subscription (root->source, subscription->source, categoryId);
+	// FIXME: leaking subscription?
+
+	// FIXME: somehow the async subscribing doesn't cause the feed list to update
 	
-	debug_exit ("theoldreader_source_add_subscription");
-	
-	return child;
+	return NULL;
 }
 
 static void
 theoldreader_source_remove_node (nodePtr node, nodePtr child) 
 { 
-	gchar           *source; 
-	TheOldReaderSourcePtr gsource = node->data;
+	gchar           	*url; 
+	TheOldReaderSourcePtr	source = (TheOldReaderSourcePtr) node->data;
 	
 	if (child == node) { 
 		feedlist_node_removed (child);
 		return; 
 	}
 
-	source = g_strdup (child->subscription->source);
+	url = g_strdup (child->subscription->source);
 
 	feedlist_node_removed (child);
 
 	/* propagate the removal only if there aren't other copies */
-	if (!theoldreader_source_opml_get_node_by_source (gsource, source)) 
-		theoldreader_source_edit_remove_subscription (gsource, source);
+	if (!feedlist_find_node (source->root, NODE_BY_URL, url)) 
+		google_reader_api_edit_remove_subscription (node->source, url);
 	
-	g_free (source);
+	g_free (url);
 }
 
 /* GUI callbacks */
@@ -315,24 +255,18 @@ on_theoldreader_source_selected (GtkDialog *dialog,
                            gpointer user_data) 
 {
 	nodePtr		node;
-	subscriptionPtr	subscription;
 
 	if (response_id == GTK_RESPONSE_OK) {
-		subscription = subscription_new ("http://theoldreader.com/reader", NULL, NULL);
 		node = node_new (node_source_get_node_type ());
-		node_set_title (node, "TheOldReader");
-		node_source_new (node, theoldreader_source_get_type ());
-		node_set_subscription (node, subscription);
+		node_source_new (node, theoldreader_source_get_type (), "http://theoldreader.com/reader");
 
-		subscription_set_auth_info (subscription,
+		subscription_set_auth_info (node->subscription,
 		                            gtk_entry_get_text (GTK_ENTRY (liferea_dialog_lookup (GTK_WIDGET(dialog), "userEntry"))),
 		                            gtk_entry_get_text (GTK_ENTRY (liferea_dialog_lookup (GTK_WIDGET(dialog), "passwordEntry"))));
 
-		subscription->type = &theOldReaderSourceOpmlSubscriptionType ; 
-
 		node->data = theoldreader_source_new (node);
 		feedlist_node_added (node);
-		theoldreader_source_update (node);
+		node_source_update (node);
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -343,7 +277,7 @@ ui_theoldreader_source_get_account_info (void)
 {
 	GtkWidget	*dialog;
 	
-	dialog = liferea_dialog_new ("theoldreader_source.ui", "theoldreader_source_dialog");
+	dialog = liferea_dialog_new ("theoldreader_source");
 	
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (on_theoldreader_source_selected), 
@@ -355,22 +289,20 @@ theoldreader_source_cleanup (nodePtr node)
 {
 	TheOldReaderSourcePtr reader = (TheOldReaderSourcePtr) node->data;
 	theoldreader_source_free(reader);
-	node->data = NULL ;
+	node->data = NULL;
 }
 
 static void 
 theoldreader_source_item_set_flag (nodePtr node, itemPtr item, gboolean newStatus)
 {
-	nodePtr root = node_source_root_from_node (node);
-	theoldreader_source_edit_mark_starred ((TheOldReaderSourcePtr)root->data, item->sourceId, node->subscription->source, newStatus);
+	google_reader_api_edit_mark_starred (node->source, item->sourceId, node->subscription->source, newStatus);
 	item_flag_state_changed (item, newStatus);
 }
 
 static void
 theoldreader_source_item_mark_read (nodePtr node, itemPtr item, gboolean newStatus)
 {
-	nodePtr root = node_source_root_from_node (node);
-	theoldreader_source_edit_mark_read ((TheOldReaderSourcePtr)root->data, item->sourceId, node->subscription->source, newStatus);
+	google_reader_api_edit_mark_read (node->source, item->sourceId, node->subscription->source, newStatus);
 	item_read_state_changed (item, newStatus);
 }
 
@@ -382,31 +314,50 @@ theoldreader_source_item_mark_read (nodePtr node, itemPtr item, gboolean newStat
 static void
 theoldreader_source_convert_to_local (nodePtr node)
 {
-	TheOldReaderSourcePtr gsource = node->data; 
-
-	gsource->loginState = THEOLDREADER_SOURCE_STATE_MIGRATE;	
+	node_source_set_state (node, NODE_SOURCE_STATE_MIGRATE);
 }
 
 /* node source type definition */
 
+extern struct subscriptionType theOldReaderSourceFeedSubscriptionType;
+extern struct subscriptionType theOldReaderSourceOpmlSubscriptionType;
+
+#define BASE_URL "https://theoldreader.com/reader/api/0/"
+
 static struct nodeSourceType nst = {
 	.id                  = "fl_theoldreader",
 	.name                = N_("TheOldReader"),
-	.description         = N_("Integrate the feed list of your TheOldReader account. Liferea will "
-	                          "present your TheOldReader subscriptions, and will synchronize your feed list and reading lists."),
 	.capabilities        = NODE_SOURCE_CAPABILITY_DYNAMIC_CREATION | 
+	                       NODE_SOURCE_CAPABILITY_CAN_LOGIN |
 	                       NODE_SOURCE_CAPABILITY_WRITABLE_FEEDLIST |
 	                       NODE_SOURCE_CAPABILITY_ADD_FEED |
+	                       NODE_SOURCE_CAPABILITY_ADD_FOLDER |
 	                       NODE_SOURCE_CAPABILITY_ITEM_STATE_SYNC |
-	                       NODE_SOURCE_CAPABILITY_CONVERT_TO_LOCAL,
+	                       NODE_SOURCE_CAPABILITY_CONVERT_TO_LOCAL |
+	                       NODE_SOURCE_CAPABILITY_GOOGLE_READER_API,
+	.api.json			= TRUE,
+	.api.subscription_list		= BASE_URL "subscription/list?output=json",
+	.api.unread_count		= BASE_URL "unread-count?all=true&client=liferea",
+	.api.token			= BASE_URL "token",
+	.api.add_subscription		= BASE_URL "subscription/edit?client=liferea",
+	.api.add_subscription_post	= "s=feed%%2F%s&ac=subscribe&T=%s",
+	.api.remove_subscription	= BASE_URL "subscription/edit?client=liferea",
+	.api.remove_subscription_post	= "s=feed%%2F%s&ac=unsubscribe&T=%s",
+	.api.edit_tag			= BASE_URL "edit-tag?client=liferea",
+	.api.edit_tag_add_post		= "i=%s&s=%s%%2F%s&a=%s&ac=edit-tags&T=%s&async=true",
+	.api.edit_tag_remove_post	= "i=%s&s=%s%%2F%s&r=%s&ac=edit-tags&T=%s&async=true",
+	.api.edit_tag_ar_tag_post	= "i=%s&s=%s%%2F%s&a=%s&r=%s&ac=edit-tags&T=%s&async=true",
+	.api.edit_add_label		= BASE_URL "subscription/edit?client=liferea",
+	.api.edit_add_label_post	= "s=%s&a=%s&ac=edit&T=%s",
+	.feedSubscriptionType = &theOldReaderSourceFeedSubscriptionType,
+	.sourceSubscriptionType = &theOldReaderSourceOpmlSubscriptionType,
 	.source_type_init    = theoldreader_source_init,
 	.source_type_deinit  = theoldreader_source_deinit,
 	.source_new          = ui_theoldreader_source_get_account_info,
-	.source_delete       = theoldreader_source_remove,
+	.source_delete       = opml_source_remove,
 	.source_import       = theoldreader_source_import,
-	.source_export       = theoldreader_source_export,
-	.source_get_feedlist = theoldreader_source_get_feedlist,
-	.source_update       = theoldreader_source_update,
+	.source_export       = opml_source_export,
+	.source_get_feedlist = opml_source_get_feedlist,
 	.source_auto_update  = theoldreader_source_auto_update,
 	.free                = theoldreader_source_cleanup,
 	.item_set_flag       = theoldreader_source_item_set_flag,
