@@ -1,7 +1,7 @@
-/**
+/*
  * @file itemset.c handling sets of items
  * 
- * Copyright (C) 2005-2011 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2017 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2005-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 #include <string.h>
 
 #include "common.h"
+#include "conf.h"
 #include "db.h"
 #include "debug.h"
 #include "enclosure.h"
@@ -62,17 +63,18 @@ itemset_get_max_item_count (itemSetPtr itemSet)
 }
 
 /**
- * Generic merge logic suitable for feeds
- *
- * @param items		existing items
- * @param newItem	new item to merge
- * @param maxChecks     maximum number of item checks
- * @param allowUpdates	TRUE if item content update is to be
+ * itemset_generic_merge_check: (skip)
+ * @items:		existing items
+ * @newItem:		new item to merge
+ * @maxChecks: 		maximum number of item checks
+ * @allowUpdates:	TRUE if item content update is to be
  *      		allowed for existing items
- * @param allowStateChanges	TRUE if item state shall be
+ * @allowStateChanges:	TRUE if item state shall be
  *				overwritten by source
  *
- * @returns TRUE if merging instead of updating is necessary) 
+ * Generic merge logic suitable for feeds
+ *
+ * Returns: TRUE if merging instead of updating is necessary)
  */
 static gboolean
 itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboolean allowUpdates, gboolean allowStateChanges)
@@ -80,6 +82,7 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 	GList		*oldItemIdIter = items;
 	itemPtr		oldItem = NULL;
 	gboolean	found, equal = FALSE;
+	guint		reason = 0;
 
 	/* determine if we should add it... */
 	debug3 (DEBUG_CACHE, "check new item for merging: \"%s\", %i, %i", item_get_title (newItem), allowUpdates, allowStateChanges);
@@ -104,28 +107,39 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 		equal = TRUE;
 
 		if (((item_get_title (oldItem) != NULL) && (item_get_title (newItem) != NULL)) && 
-		     (0 != strcmp (item_get_title (oldItem), item_get_title (newItem))))		
+		     (0 != strcmp (item_get_title (oldItem), item_get_title (newItem)))) {
 	    		equal = FALSE;
+			reason |= 1;
+		}
 
 		if (((item_get_description (oldItem) != NULL) && (item_get_description (newItem) != NULL)) && 
-		     (0 != strcmp (item_get_description(oldItem), item_get_description (newItem))))
+		     (0 != strcmp (item_get_description(oldItem), item_get_description (newItem)))) {
 	    		equal = FALSE;
+			reason |= 2;
+		}
 
 		/* best case: they both have ids (position important: id check is useless without knowing if the items are different!) */
 		if (item_get_id (oldItem)) {			
 			if (0 == strcmp (item_get_id (oldItem), item_get_id (newItem))) {
 				found = TRUE;
 
-				/* found corresponding item, check if they are REALLY equal (eg, read status may have changed) */
-				if(oldItem->readStatus != newItem->readStatus) 
-					equal = FALSE;
-				if(oldItem->flagStatus != newItem->flagStatus)
-					equal = FALSE;
+				if (allowStateChanges) {
+					/* found corresponding item, check if they are REALLY equal (eg, read status may have changed) */
+					if(oldItem->readStatus != newItem->readStatus) {
+						equal = FALSE;
+						reason |= 4;
+					}
+					if(oldItem->flagStatus != newItem->flagStatus) {
+						equal = FALSE;
+						reason |= 8;
+					}
+				}
 				break;
 			} else {
 				/* different ids, but the content might be still equal (e.g. empty)
 				   so we need to explicitly unset the equal flag !!!  */
 				equal = FALSE;
+				reason |= 16;
 			}
 		}
 			
@@ -133,11 +147,6 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 			found = TRUE;
 			break;
 		}
-		
-/*		if (i++ > maxChecks) {
-			found = FALSE;
-			break;
-		}*/
 
 		oldItemIdIter = g_list_next (oldItemIdIter);
 	}
@@ -168,12 +177,16 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 				   which means online accounts we sync against, but not normal
 				   online feeds where items have no read status. */
 				if (allowStateChanges) {
-					oldItem->readStatus = newItem->readStatus;
+					/* To avoid notification spam from external
+					   sources: never set read items to unread again! */
+					if ((!oldItem->readStatus) && (newItem->readStatus))
+						oldItem->readStatus = newItem->readStatus;
+
 					oldItem->flagStatus = newItem->flagStatus;
 				}
 				
 				db_item_update (oldItem);
-				debug0 (DEBUG_CACHE, "-> item already existing and was updated");
+				debug1 (DEBUG_CACHE, "-> item already existing and was updated, reason %x", reason);
 			} else {
 				debug0 (DEBUG_CACHE, "-> item updates not merged because of parser errors");
 			}
@@ -189,6 +202,7 @@ static gboolean
 itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item, gint maxChecks, gboolean allowUpdates)
 {
 	gboolean	allowStateChanges = FALSE;
+	gboolean	html5_enabled;
 	gboolean	merge;
 	nodePtr		node;
 
@@ -215,10 +229,14 @@ itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item, gint maxChec
 		
 		/* step 2: add to itemset */
 		itemSet->ids = g_list_prepend (itemSet->ids, GUINT_TO_POINTER (item->id));
+
+		/* step 3: enrich item description */
+		if (node && IS_FEED (node) && ((feedPtr)node->data)->html5Extract)
+			feed_enrich_item (node->subscription, item);
 				
 		debug3 (DEBUG_UPDATE, "-> added \"%s\" (id=%d) to item set %p...", item_get_title (item), item->id, itemSet);
 		
-		/* step 3: duplicate detection, mark read if it is a duplicate */
+		/* step 4: duplicate detection, mark read if it is a duplicate */
 		if (item->validGuid) {
 			GSList	*iter, *duplicates;
 
@@ -236,13 +254,13 @@ itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item, gint maxChec
 			g_slist_free (duplicates);
 		}
 
-		/* step 4: Check item for new enclosures to download */
+		/* step 5: Check item for new enclosures to download */
 		if (node && (((feedPtr)node->data)->encAutoDownload)) {
 			GSList *iter = metadata_list_get_values (item->metadata, "enclosure");
 			while (iter) {
 				enclosurePtr enc = enclosure_from_string (iter->data);
 				debug1 (DEBUG_UPDATE, "download enclosure (%s)", (gchar *)iter->data);
-				enclosure_save_as_file (NULL, enc->url, NULL);
+				enclosure_download (NULL, enc->url, FALSE /* non interactive */);
 				iter = g_slist_next (iter);
 				enclosure_free (enc);
 			}
@@ -289,7 +307,7 @@ guint
 itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates, gboolean markAsRead)
 {
 	GList	*iter, *droppedItems = NULL, *items = NULL;
-	guint	max, length, toBeDropped, newCount = 0, flagCount = 0;
+	guint	i, max, length, toBeDropped, newCount = 0, flagCount = 0;
 
 	debug_start_measurement (DEBUG_UPDATE);
 	
@@ -344,20 +362,19 @@ itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates, gbo
 	   merges with the same feed content */
 	if (length > max) {
 		debug2 (DEBUG_UPDATE, "item list too long (%u, max=%u) for merging!", length, max);
-		guint i = 0;
-		GList *iter, *copy;
-		iter = copy = g_list_copy (list);
-		while (iter) {
-			i++;
-			if (i > max) {
-				itemPtr item = (itemPtr) iter->data;
-				debug2 (DEBUG_UPDATE, "ignoring item nr %u (%s)...", i, item_get_title(item));
-				item_unload (item);
-				list = g_list_remove (list, item);
-			}
+
+		/* reach max element */
+		for(i = 0, iter = list; (i < max) && iter; ++i)        
 			iter = g_list_next (iter);
+
+		/* and remove all following elements */
+		while (iter) {
+			itemPtr item = (itemPtr) iter->data;
+			debug2 (DEBUG_UPDATE, "ignoring item nr %u (%s)...", ++i, item_get_title (item));
+			item_unload (item);
+			iter = g_list_next (iter);
+			list = g_list_remove (list, item);
 		}
-		g_list_free (copy);
 	}	 
  
 	/* 3. Merge received items to existing item set
@@ -375,7 +392,6 @@ itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates, gbo
 			item->readStatus = TRUE;
 			
 		if (itemset_merge_item (itemSet, items, item, length, allowUpdates)) {
-			vfolder_foreach_data (vfolder_merge_item, item);
 			newCount++;
 			items = g_list_prepend (items, iter->data);
 		}
@@ -396,13 +412,6 @@ itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates, gbo
 		toBeDropped = g_list_length (items) - max;
 	else
 		toBeDropped = 0;
-
-	/* Let's never drop more than 50 items at one time to avoid
-	   long duration migrations. It is ok to drop only some of the
-	   items here, because we can drop the rest during future
-	   feed updates. */
-	//if(toBeDropped > 50)
-	//	toBeDropped = 50;
 	
 	debug3 (DEBUG_UPDATE, "%u new items, cache limit is %u -> dropping %u items", newCount, max, toBeDropped);
 	items = g_list_sort (items, itemset_sort_by_date);
@@ -449,7 +458,7 @@ itemset_check_item (itemSetPtr itemSet, itemPtr item)
 		
 		ruleResult = (*func) (rule, item);
 		result &= (rule->additive)?ruleResult:!ruleResult;
-		if (itemSet->anyMatch && result)
+		if (itemSet->anyMatch && ruleResult)
 			return TRUE;
 
 		iter = g_slist_next (iter);
@@ -458,12 +467,6 @@ itemset_check_item (itemSetPtr itemSet, itemPtr item)
 	return result;
 }
 
-gboolean
-itemset_has_item_id (itemSetPtr itemSet, gulong id)
-{
-	return (NULL != g_list_find (itemSet->ids, GUINT_TO_POINTER (id)));
-}
-
 void
 itemset_add_rule (itemSetPtr itemSet,
                   const gchar *ruleId,
