@@ -1,7 +1,7 @@
 /**
  * @file newsbin.c  news bin node type implementation
  * 
- * Copyright (C) 2006-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2006-2016 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,9 +29,8 @@
 #include "itemlist.h"
 #include "metadata.h"
 #include "render.h"
-#include "vfolder.h"
 #include "ui/icons.h"
-#include "ui/ui_node.h"
+#include "ui/feed_list_node.h"
 #include "ui/liferea_dialog.h"
 
 static GtkWidget *newnewsbindialog = NULL;
@@ -83,7 +82,7 @@ ui_newsbin_add (void)
 	GtkWidget	*nameentry;
 	
 	if (!newnewsbindialog || !G_IS_OBJECT (newnewsbindialog))
-		newnewsbindialog = liferea_dialog_new (NULL, "newnewsbindialog");
+		newnewsbindialog = liferea_dialog_new ("new_newsbin");
 
 	nameentry = liferea_dialog_lookup (newnewsbindialog, "newsbinnameentry");
 	gtk_entry_set_text (GTK_ENTRY (nameentry), "");
@@ -145,7 +144,7 @@ newsbin_get_node_type (void)
 
 	if (!nodeType) {
 		/* derive the plugin node type from the folder node type */
-		nodeType = (nodeTypePtr)g_new0(struct nodeType, 1);
+		nodeType = g_new0 (struct nodeType, 1);
 		nodeType->capabilities		= NODE_CAPABILITY_RECEIVE_ITEMS |
 		                                  NODE_CAPABILITY_SHOW_UNREAD_COUNT |
 		                                  NODE_CAPABILITY_SHOW_ITEM_COUNT;
@@ -159,7 +158,7 @@ newsbin_get_node_type (void)
 		nodeType->remove		= newsbin_remove;
 		nodeType->render		= newsbin_render;
 		nodeType->request_add		= ui_newsbin_add;
-		nodeType->request_properties	= ui_node_rename;
+		nodeType->request_properties	= feed_list_node_rename;
 		nodeType->free			= feed_get_node_type()->free;
 	}
 
