@@ -1,7 +1,7 @@
 /**
  * @file rss_channel.c  some tolerant and generic RSS/RDF channel parsing
  *
- * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2010 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2005-2006 Nathan Conrad <t98502@users.sourceforge.net> 
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,14 +17,15 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
  */
+#include "rss_channel.h"
 
 #include <string.h>
 #include <stdlib.h>
 
-#include "conf.h"
 #include "common.h"
-#include "rss_channel.h"
+#include "date.h"
 #include "feed_parser.h"
 #include "feedlist.h"
 #include "metadata.h"
@@ -88,21 +89,21 @@ static void parseChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur) {
 			
 		/* Check for metadata tags */
 		if(NULL != (tmp2 = g_hash_table_lookup(RssToMetadataMapping, cur->name))) {
-			if(NULL != (tmp3 = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, TRUE)))) {
+			if(NULL != (tmp3 = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, TRUE))) {
 				ctxt->subscription->metadata = metadata_list_append(ctxt->subscription->metadata, tmp2, tmp3);
 				g_free(tmp3);
 			}
 		}	
 		/* check for specific tags */
 		else if(!xmlStrcmp(cur->name, BAD_CAST"pubDate")) {
- 			if(NULL != (tmp = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1)))) {
+ 			if(NULL != (tmp = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1))) {
 				ctxt->subscription->metadata = metadata_list_append(ctxt->subscription->metadata, "pubDate", tmp);
-				ctxt->feed->time = parseRFC822Date(tmp);
+				ctxt->feed->time = date_parse_RFC822 (tmp);
 				g_free(tmp);
 			}
 		} 
 		else if(!xmlStrcmp(cur->name, BAD_CAST"ttl")) {
- 			if(NULL != (tmp = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, TRUE)))) {
+ 			if(NULL != (tmp = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, TRUE))) {
 				subscription_set_default_update_interval(ctxt->subscription, atoi(tmp));
 				g_free(tmp);
 			}
@@ -121,7 +122,7 @@ static void parseChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur) {
 			}
 		}
 		else if (!xmlStrcmp (cur->name, BAD_CAST"description")) {
- 			tmp = common_utf8_fix (xhtml_extract (cur, 0, NULL));
+ 			tmp = xhtml_extract (cur, 0, NULL);
 			if (tmp) {
 				metadata_list_set (&ctxt->subscription->metadata, "description", tmp);
 				g_free (tmp);
@@ -148,10 +149,10 @@ static gchar* parseTextInput(xmlNodePtr cur) {
 				tiDescription = xhtml_extract (cur, 0, NULL);
 			} else if(!xmlStrcmp(cur->name, BAD_CAST"name")) {
 				g_free(tiName);
-				tiName = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
+				tiName = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1);
 			} else if(!xmlStrcmp(cur->name, BAD_CAST"link")) {
 				g_free(tiLink);
-				tiLink = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
+				tiLink = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1);
 			}
 		}
 		cur = cur->next;
@@ -188,7 +189,7 @@ static gchar* parseImage(xmlNodePtr cur) {
 	while (cur != NULL) {
 		if (cur->type == XML_ELEMENT_NODE) {
 			if (!xmlStrcmp(cur->name, BAD_CAST"url")) {
-				tmp = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
+				tmp = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1);
 				if(NULL != tmp) {
 					return tmp;
 				}
@@ -378,11 +379,8 @@ rss_init_feed_handler (void)
 							
 	/* prepare feed handler structure */
 	fhp->typeStr = "rss";
-	fhp->icon = ICON_AVAILABLE;
 	fhp->feedParser	= rss_parse;
 	fhp->checkFormat = rss_format_check;
-	fhp->merge = TRUE;
-	fhp->noXML = TRUE; /* FIXME: this should be valid for RSS 0.9x only */
 	
 	return fhp;
 }
