@@ -1,7 +1,7 @@
 /**
  * @file enclosure-list-view.h enclosures list view
  *
- * Copyright (C) 2005-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2008 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,6 +79,16 @@ GtkWidget * enclosure_list_view_get_widget (EnclosureListView *elv);
  */
 void enclosure_list_view_load (EnclosureListView *elv, itemPtr item);
 
+/**
+ * enclosure_list_view_select:
+ *
+ * Select the nth enclosure in the enclosure list.
+ *
+ * @elv:	the enclosure list view
+ * @position:	the position to select
+ */
+void enclosure_list_view_select (EnclosureListView *elv, guint position);
+
 /**
  * Hides the enclosure list view.
  *
@@ -92,9 +102,8 @@ void on_popup_open_enclosure(gpointer callback_data);
 void on_popup_save_enclosure(gpointer callback_data);
 void on_popup_copy_enclosure(gpointer callback_data);
 
-// FIXME: these do not belong here!
+// FIXME: this does not belong here!
 void ui_enclosure_change_type (encTypePtr type);
-void ui_enclosure_remove_type (encTypePtr type);
 
 G_END_DECLS
 
