@@ -1,7 +1,7 @@
 /**
  * @file subscription_dialog.c  property dialog for feed subscriptions
  *
- * Copyright (C) 2004-2011 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2004-2017 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,12 +34,12 @@
 #include "update.h"
 #include "ui/liferea_dialog.h"
 #include "ui/ui_common.h"
-#include "ui/ui_node.h"
+#include "ui/feed_list_node.h"
 
 /* Note: these update interval literals should be kept in sync with the 
    ones in ui_prefs.c! */
     
-static gchar * default_update_interval_unit_options[] = {
+static const gchar * default_update_interval_unit_options[] = {
 	N_("minutes"),
 	N_("hours"),
 	N_("days"),
@@ -128,13 +128,13 @@ ui_subscription_create_url (gchar *url,
 
 	/* Use the values in the textboxes if also specified in the URL! */
 	if(auth) {
-		xmlURIPtr uri = xmlParseURI(BAD_CAST str);
+		xmlURIPtr uri = xmlParseURI(str);
 		if (uri != NULL) {
 			xmlChar *sourceUrl;
 			xmlFree(uri->user);
 			uri->user = g_strdup_printf("%s:%s", username, password);
 			sourceUrl = xmlSaveUri(uri);
-			source = g_strdup(sourceUrl);
+			source = g_strdup((gchar *) sourceUrl);
 			g_free(uri->user);
 			uri->user = NULL;
 			xmlFree(sourceUrl);
@@ -249,16 +249,12 @@ on_propdialog_response (GtkDialog *dialog,
 
 		/* "Advanced" options */
 		feed->encAutoDownload = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "enclosureDownloadCheck")));
-		node->loadItemLink = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "loadItemLinkCheck")));
-		feed->ignoreComments = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "ignoreCommentFeeds")));
-		feed->enforcePopup = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "enforcePopupCheck")));
-		feed->preventPopup = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "preventPopupCheck")));
-		feed->markAsRead = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "markAsReadCheck")));
+		node->loadItemLink    = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "loadItemLinkCheck")));
+		feed->ignoreComments  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "ignoreCommentFeeds")));
+		feed->markAsRead      = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "markAsReadCheck")));
+		feed->html5Extract    = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "html5ExtractCheck")));
 		
-		if (feed->enforcePopup && feed->preventPopup)
-			feed->enforcePopup = FALSE;
-
-		ui_node_update (node->id);
+		feed_list_node_update (node->id);
 		feedlist_schedule_save ();
 		db_subscription_update (subscription);
 		if (needsUpdate)
@@ -353,7 +349,7 @@ on_selectfile_pressed (GtkButton *button,
 	}
 	
 	name = g_filename_from_utf8 (utfname, -1, NULL, NULL, NULL);
-	ui_choose_file (_("Choose File"), GTK_STOCK_OPEN, FALSE, on_selectfileok_clicked, name, NULL, NULL, NULL, ui_data);
+	ui_choose_file (_("Choose File"), _("_Open"), FALSE, on_selectfileok_clicked, name, NULL, NULL, NULL, ui_data);
 	g_free (name);
 }
  
@@ -444,7 +440,7 @@ subscription_prop_dialog_load (SubscriptionPropDialog *spd,
 			ui_subscription_prop_enable_httpauth(spd->priv, FALSE);
 			gtk_widget_set_sensitive(spd->priv->selectFile, TRUE);
 		} else if(strstr(subscription_get_source(subscription), "://") != NULL) {
-			xmlURIPtr uri = xmlParseURI(BAD_CAST subscription_get_source(subscription));
+			xmlURIPtr uri = xmlParseURI(subscription_get_source(subscription));
 			xmlChar *parsedUrl;
 			if(uri) {
 				if(uri->user) {
@@ -461,7 +457,7 @@ subscription_prop_dialog_load (SubscriptionPropDialog *spd,
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(spd->priv->authcheckbox), TRUE);
 				}
 				parsedUrl = xmlSaveUri(uri);
-				gtk_entry_set_text(GTK_ENTRY(spd->priv->sourceEntry), parsedUrl);
+				gtk_entry_set_text(GTK_ENTRY(spd->priv->sourceEntry), (gchar *) parsedUrl);
 				xmlFree(parsedUrl);
 				xmlFreeURI(uri);
 			} else {
@@ -506,13 +502,12 @@ subscription_prop_dialog_load (SubscriptionPropDialog *spd,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "enclosureDownloadCheck")), feed->encAutoDownload);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "loadItemLinkCheck")), node->loadItemLink);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "ignoreCommentFeeds")), feed->ignoreComments);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "enforcePopupCheck")), feed->enforcePopup);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "preventPopupCheck")), feed->preventPopup);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "markAsReadCheck")), feed->markAsRead);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "html5ExtractCheck")), feed->html5Extract);
 
 	/* Remove tabs we do not need... */
 	if (SUBSCRIPTION_TYPE(subscription) != feed_get_subscription_type ()) {
-		/* Remove "Allgemein", "Source" and "Download" tab */
+		/* Remove "General", "Source" and "Download" tab */
 		gtk_notebook_remove_page (GTK_NOTEBOOK (liferea_dialog_lookup (spd->priv->dialog, "subscriptionPropNotebook")), 0);
 		gtk_notebook_remove_page (GTK_NOTEBOOK (liferea_dialog_lookup (spd->priv->dialog, "subscriptionPropNotebook")), 0);
 		gtk_notebook_remove_page (GTK_NOTEBOOK (liferea_dialog_lookup (spd->priv->dialog, "subscriptionPropNotebook")), 1);
@@ -525,7 +520,7 @@ subscription_prop_dialog_init (SubscriptionPropDialog *spd)
 	GtkWidget	*propdialog;
 	
 	spd->priv = SUBSCRIPTION_PROP_DIALOG_GET_PRIVATE (spd);
-	spd->priv->dialog = propdialog = liferea_dialog_new (NULL, "propdialog");
+	spd->priv->dialog = propdialog = liferea_dialog_new ("properties");
 
 	/* set default update interval spin button and unit combo box */
 	ui_common_setup_combo_menu (liferea_dialog_lookup (propdialog, "refreshIntervalUnitComboBox"),
@@ -545,7 +540,7 @@ subscription_prop_dialog_init (SubscriptionPropDialog *spd)
 	spd->priv->authcheckbox = liferea_dialog_lookup (propdialog, "HTTPauthCheck");
 	spd->priv->username = liferea_dialog_lookup (propdialog, "usernameEntry");
 	spd->priv->password = liferea_dialog_lookup (propdialog, "passwordEntry");
-	spd->priv->credTable = liferea_dialog_lookup (propdialog, "table4");
+	spd->priv->credTable = liferea_dialog_lookup (propdialog, "httpAuthBox");
 	
 	g_signal_connect (spd->priv->selectFile, "clicked", G_CALLBACK (on_selectfile_pressed), spd->priv);
 	g_signal_connect (spd->priv->urlRadio, "toggled", G_CALLBACK (on_feed_prop_url_radio), spd->priv);
@@ -638,7 +633,7 @@ new_subscription_dialog_init (NewSubscriptionDialog *nsd)
 	GtkWidget	*newdialog;
 	
 	nsd->priv = NEW_SUBSCRIPTION_DIALOG_GET_PRIVATE (nsd);
-	nsd->priv->dialog = newdialog = liferea_dialog_new ("new_subscription.ui", "newdialog");
+	nsd->priv->dialog = newdialog = liferea_dialog_new ("new_subscription");
 	
 	/* Setup source entry */
 	nsd->priv->sourceEntry = liferea_dialog_lookup (newdialog,"sourceEntry");
@@ -733,7 +728,7 @@ simple_subscription_dialog_init (SimpleSubscriptionDialog *ssd)
 	GtkWidget	*newdialog;
 	
 	ssd->priv = SIMPLE_SUBSCRIPTION_DIALOG_GET_PRIVATE (ssd);
-	ssd->priv->dialog = newdialog = liferea_dialog_new ("simple_subscription.ui", "simplenewdialog");
+	ssd->priv->dialog = newdialog = liferea_dialog_new ("simple_subscription");
 	
 	/* Setup source entry */
 	ssd->priv->sourceEntry = liferea_dialog_lookup (newdialog, "sourceEntry");
